@@ -185,22 +185,30 @@ def SavedDeviceGrantAuth(
         retries (int): number of retries to attempt (optional)
     """
     logger = logging.getLogger('SavedDeviceGrantAuth')
-
     filepath = Path(filename)
-    refresh_token = _load_token_from_file(filepath)
-
-    if not refresh_token:
-        auth = OpenIDAuth(token_url)
-        if not auth.provider_info:
-            raise RuntimeError('Token service does not support .well-known discovery')
-        if 'device_authorization_endpoint' not in auth.provider_info:
-            raise RuntimeError('Device grant not supported by server')
-        endpoint = auth.provider_info['device_authorization_endpoint']
-        refresh_token = _perform_device_grant(logger, endpoint, auth.token_url, client_id, client_secret, scopes)
 
     def update_func(access, refresh):
         _save_token_to_file(filepath, refresh)
 
+    refresh_token = _load_token_from_file(filepath)
+    if refresh_token:
+        try:
+            # this will try to refresh, and raise if it fails
+            return OpenIDRestClient(address=address, token_url=token_url, client_id=client_id,
+                                    client_secret=client_secret, refresh_token=refresh_token,
+                                    update_func=update_func, **kwargs)
+        except Exception:
+            pass
+
+    auth = OpenIDAuth(token_url)
+    if not auth.provider_info:
+        raise RuntimeError('Token service does not support .well-known discovery')
+    if 'device_authorization_endpoint' not in auth.provider_info:
+        raise RuntimeError('Device grant not supported by server')
+    endpoint = auth.provider_info['device_authorization_endpoint']
+
+    refresh_token = _perform_device_grant(logger, endpoint, auth.token_url, client_id, client_secret, scopes)
+
     return OpenIDRestClient(address=address, token_url=token_url, client_id=client_id,
                             client_secret=client_secret, refresh_token=refresh_token,
                             update_func=update_func, **kwargs)
